# coding=utf-8
# https://blog.ixxoo.me/argparse.html
# https://docs.python.org/2/library/argparse.html#module-argparse 有了这篇文章一切就搞定了

"""
author: wangssuyan@baidu.com
time: 2019-01-25
"""

import pprint
import argparse
import ku_dot
import ku_img_found

"""
错误总结：

 case1：命令程序需要一个参数，却未指定
➜  tools python3 ku.py
usage: ku.py [-h] dot
ku.py: error: the following arguments are required: dot

➜  tools python3 ku.py foo
参数错误，命令行程序没有这个参数
ku.py: error: unrecognized arguments: foo

参数写错了，应该是 --verbose 而不是 -verbose
➜  tools python3 ku.py 11 111 111 11111 -verbose
usage: ku.py [-h] [-v] dot dot_header dot_source_path dot_dest_path
ku.py: error: argument -v/--verbose: ignored explicit argument 'erbose'
➜  tools python3 ku.py 11 111 111 11111 --verbose

参数的值错误，只能为 0，1，2
➜  tools python3 log.py 4 -v 3
usage: log.py [-h] [-v {0,1,2}] square
log.py: error: argument -v/--verbosity: invalid choice: 3 (choose from 0, 1, 2)
"""


# prog 参数为命令行工具的名字
parser = argparse.ArgumentParser(description="ku 是百度文库iOS命令行工具，只为提升你的效率！", prog="ku")

# 命令执行的函数
# 日志打点工具
def dot(args):
    """
    usage: ku dot [-h] dot_header dot_source_path dot_dest_path

    positional arguments:
    dot_header       用来解析打点文件，打点文件有固定的格式
    dot_source_path  指定要解析文件的路径，文件必须为CSV文件
    """

    # ku_dot.excute('/Users/wangsuyan/Desktop/baidu/tools/upload_answer.csv')
    ku_dot.excute(args.verbose, args.dot_header, args.dot_source_path)

def img(args):
    print("🔍 正在查找名为 %s 的图片......\n"%(args.img_name))
    ressult = set()
    ku_img_found.find_image(args.img_path, args.img_name, ressult)
    if len(ressult) > 0:
        print("🔍  共找到了 %s 张图片"%(len(ressult)))
    else:
        print("🔍  未找到你要查找的图")

"""
文库打点日志工具，用来解析日志并自动生成打点代码片段

命令执行方法:

ku dot uploadAnswer ./Desktop/wsy.log ./Desktop/result.log 

帮助信息，自动生成的
ku.py -h


"""

"""
添加参数，执行命令时就需要使用这个参数，并指定输入值的类型为字符串
执行 python3 ku.py 1111，args.dot 的值就为 1111
"""

# 执行子，命令时可以找到对应的名字
subparsers = parser.add_subparsers(help="subcommands", dest='subparser_name')

# 打点工具 ===================
dot_parser = subparsers.add_parser('dot', help="自动生成打点代码工具")
# parser.add_argument('dot', help="解析打点日志工具", type=str)
dot_parser.add_argument('dot_header', help="用来解析打点文件，打点文件有固定的格式", type=str)
dot_parser.add_argument('dot_source_path', help="指定要解析文件的路径，文件必须为CSV文件", type=str)
# dot_parser.add_argument('dot_dest_path', help="指定解析文件完成后保存的路径", type=str)
dot_parser.set_defaults(func=dot)


# image 工具 ===================
img_parser = subparsers.add_parser('img', help="根据图片名，找到图片在项目的位置")
img_parser.add_argument('img_path', help="项目地址")
img_parser.add_argument('img_name', help="项目地址")
img_parser.set_defaults(func=img)

# 全局配置 ========================
# ➜  tools python3 ku.py 11 111 111 11111 -verbose 1 可选参数-verbose后必须添加值
# parser.add_argument('--verbose', help="显示帮助信息")

# # ➜  tools python3 ku.py 11 111 111 11111 -verbose 可选参数-verbose后不需要添加值，如果指定 -verbose
# parser.add_argument('--verbose', help="显示帮助信息", action="store_true")
parser.add_argument('-v', "--verbose", help="显示更多信息", action="store_true")

# 解析命令
args = parser.parse_args()
# 调用命令中的函数
args.func(args)




# coding=utf-8 

import os
import re
import csv
import sys

LOG_DEST_DOT = '/Users/wangsuyan/Desktop/dot.txt'
LOG_DEST_CODE = '/Users/wangsuyan/Desktop/code.txt'

# 桌面打点文件
def dot_path():
    return os.path.join(os.path.expanduser("~"), 'Desktop/ku_dot.txt')

# 桌面代码文件
def code_path():
    return os.path.join(os.path.expanduser("~"), 'Desktop/ku_code.txt')

def is_num(text):
    regx = '[^0-9]'
    matchs = re.findall(regx, text)
    return len(matchs) == 0

def excute(is_verbose, header, source_path):
    if is_verbose:
        print('🐶 begin parse csv file ......')
    with open(source_path, 'rU') as csv_file:
        csv_reader = csv.reader(csv_file, delimiter=',')
        log_str_file = open(dot_path(), 'w')
        log_code_file = open(code_path(), 'w')
        for row in csv_reader:
            if len(row) < 2:
                if is_verbose:
                    print('❌ find a row is error, length than 2')
                continue
            if not is_num(row[1]):
                if is_verbose:
                    print('❌ is not a valid item: ' + row[1])
                continue

            # static NSString *const LOG_COOKIE_LOSE_5666 = @"5666";
            # item_value = "static NSString *const" + ' ' + LOG_HEADER + row[1] + ' = ' +  row[1] + ';'
            log_name = "%s_%s"%(header, row[1])
            item_value = "static NSString *const %s = @\"%s\";"%(log_name, row[1])
            item_comment = "/*** " + row[0]
            if len(row)>2:
                item_comment += row[2]
            item_comment += ' */'
            # print item_comment.decode('gb2312')
            # print item_value
            log_str_file.writelines([item_comment, '\n', item_value, '\n\n'])
            if len(row) > 2 and len(row[2]) > 0:
                log_code = "[BDELogManager logActionWithId:%s params:@{@\"type\" : @(1)}];"%(log_name)
            else:
                log_code = "[BDELogManager logActionWithId:%s];"%(log_name)
            log_code_file.writelines([log_code, '\n\n'])

        print('✅ parse successful, code saved to %s, dot saved to %s'%(code_path(), dot_path()))




import setuptools

with open('README.md', "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ku",
    version="0.0.1",
    author="Lefex",
    author_email="wsyxyxs@126.com",
    description="A serials of tools for iOS develper",
    long_description=long_description,
    url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)


# coding=utf-8 

import os
import re
import shutil

# 是否为图片
def isimage(filePath):
    ext = os.path.splitext(filePath)[1]
    return ext == '.png' or ext == '.jpg' or ext == '.jpeg' or ext == '.gif'

def filename(filePath, orgin_name):
    name = os.path.split(filePath)[1]
    # 搜索的图片名字有后缀，直接返回
    if orgin_name.endswith('.png'):
        return name
    # 把图片的后缀去掉
    name = name.replace('@2x.png', '')
    namev = name.replace('@3x.png', '')
    return name


def find_image(project_path, image_name, ressult):
    paths = os.listdir(project_path)
    for aCompent in paths:
        aPath = os.path.join(project_path, aCompent)
        ext = os.path.splitext(aPath)[1]
        if os.path.isdir(aPath):
            find_image(aPath, image_name, ressult)
        elif os.path.isfile(aPath) and isimage(aPath):
            if filename(aPath, image_name) == image_name:
                ressult.add(aPath)
                print("🔍 查找到一张图片在：%s"%(aPath))
                break 